@@ -64,6 +64,9 @@ import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.mime.MimeDefaultSession;
 import com.openexchange.mail.mime.utils.MimeMessageUtility;
 import com.openexchange.mail.service.MailService;
+import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.mailaccount.MailAccountStorageService;
+import com.openexchange.mailaccount.MailAccounts;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
@@ -123,6 +126,10 @@ public class SpamExpertsSpamHandler extends SpamHandler {
         props.put("mail.imap.socketFactory.port", Integer.toString(imapUrl.getPort()));
         props.put("mail.imap.socketFactory.fallback", "false");
 
+        if (isPrimaryImapAccount(imapUrl.getHost(), imapUrl.getPort(), session.getUserId(), session.getContextId())) {
+            props.put("mail.imap.primary", "true");
+        }
+
         javax.mail.Session imapSession = javax.mail.Session.getInstance(props, null);
 
         IMAPStore imapStore = null;
@@ -160,6 +167,30 @@ public class SpamExpertsSpamHandler extends SpamHandler {
         }
     }
 
+    /**
+     * Checks if given host/port denote the primary IMAP account of specified user.
+     *
+     * @param host The host
+     * @param port The port
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @return <code>true</code> if given host/port denote the primary IMAP account; otherwise <code>false</code>
+     */
+    private boolean isPrimaryImapAccount(String host, int port, int userId, int contextId) {
+        try {
+            MailAccountStorageService storageService = services.getOptionalService(MailAccountStorageService.class);
+            if (storageService == null) {
+                return false;
+            }
+
+            MailAccount defaultMailAccount = storageService.getDefaultMailAccount(userId, contextId);
+            return MailAccounts.isEqualImapAccount(defaultMailAccount, host, port);
+        } catch (Exception e) {
+            LOG.warn("Failed to check for primary IMAP account of user {} in context {}", I(userId), I(contextId), e);
+           return false;
+        }
+    }
+
     @Override
     public void handleHam(int accountId, String spamFullName, String[] mailIDs, boolean move, Session session) throws OXException {
         LOG.debug("handleHam");
