@@ -58,10 +58,14 @@ import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.mail.service.MailService;
+import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.rest.client.httpclient.SpecificHttpClientConfigProvider;
+import com.openexchange.rest.client.httpclient.HttpClientService;
 import com.openexchange.spamhandler.SpamHandler;
 import com.openexchange.spamhandler.spamexperts.SpamExpertsSpamHandler;
+import com.openexchange.spamhandler.spamexperts.http.SpamExtertsHttpConfiguration;
 import com.openexchange.spamhandler.spamexperts.management.SpamExpertsConfig;
 import com.openexchange.spamhandler.spamexperts.servlets.SpamExpertsServlet;
 import com.openexchange.tools.servlet.http.HTTPServletRegistration;
@@ -71,7 +75,6 @@ import com.openexchange.version.VersionService;
 public class SpamExpertsActivator extends HousekeepingActivator {
 
 	private HTTPServletRegistration servletRegistration;
-    private SpamExpertsServlet spamExpertsServlet;
 
 	public SpamExpertsActivator() {
 		super();
@@ -80,13 +83,16 @@ public class SpamExpertsActivator extends HousekeepingActivator {
 	@Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { UserService.class, DatabaseService.class, ContextService.class, ConfigurationService.class, ConfigViewFactory.class, 
-                                HttpService.class, MailService.class, SSLSocketFactoryProvider.class, VersionService.class };
+                                HttpService.class, MailService.class, SSLSocketFactoryProvider.class, HttpClientService.class, VersionService.class };
     }
 
 	@Override
 	protected synchronized void startBundle() throws Exception {
 	    org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(SpamExpertsActivator.class);
         logger.info("starting bundle: \"com.openexchange.spamhandler.spamexperts\"");
+        
+        trackService(MailAccountStorageService.class);
+        openTrackers();
 
 	    final SpamExpertsConfig config = new SpamExpertsConfig(this);
 
@@ -105,9 +111,9 @@ public class SpamExpertsActivator extends HousekeepingActivator {
         });
 
         String alias = getService(ConfigurationService.class).getProperty("com.openexchange.custom.spamexperts.panel_servlet", "/ajax/spamexperts/panel").trim();
-		SpamExpertsServlet spamExpertsServlet = new SpamExpertsServlet(config, getServiceSafe(VersionService.class));
-		this.spamExpertsServlet = spamExpertsServlet;
+		SpamExpertsServlet spamExpertsServlet = new SpamExpertsServlet(config, this);
         servletRegistration = new HTTPServletRegistration(context, spamExpertsServlet, alias);
+        registerService(SpecificHttpClientConfigProvider.class, new SpamExtertsHttpConfiguration(getService(VersionService.class)));
 	}
 
 	@Override
@@ -120,13 +126,6 @@ public class SpamExpertsActivator extends HousekeepingActivator {
             this.servletRegistration = null;
             servletRegistration.unregister();
         }
-
-        SpamExpertsServlet spamExpertsServlet = this.spamExpertsServlet;
-        if (null != spamExpertsServlet) {
-            this.spamExpertsServlet = null;
-            spamExpertsServlet.shutDown();
-        }
-
         super.stopBundle();
 	}
 
